@@ -89,11 +89,13 @@ public:
         // 2. disable conflicting actions
         // 3. replace conflicting actions in the action collection
         KActionCollection *ac = canvas->actionCollection();
+
         QHash<QString, KAction*> toolActions = activeTool->actions();
         QHash<QString, KAction*>::const_iterator it(toolActions.constBegin());
+
         for (; it != toolActions.constEnd(); ++it) {
             if (ac) {
-                QAction* action = ac->action(it.key());
+                KAction* action = qobject_cast<KAction*>(ac->action(it.key()));
                 if (action) {
                     ac->takeAction(action);
                     if (action != it.value()) {
@@ -104,7 +106,6 @@ public:
                             disabledDisabledActions.append(action);
                         }
                     }
-                    it.value()->setShortcut(action->shortcut());
                 }
                 ac->addAction(it.key(), it.value());
             }
@@ -114,16 +115,18 @@ public:
 
     void deactivateToolActions()
     {
+
         if (!activeTool)
             return;
         // disable actions of active tool
         foreach(KAction *action, activeTool->actions()) {
             action->setEnabled(false);
         }
-        // enable actions which where disables on activating the active tool
+
+        // enable actions which where disabled on activating the active tool
         // and re-add them to the action collection
         KActionCollection *ac = canvas->actionCollection();
-        foreach(QAction *action, disabledDisabledActions) {
+        foreach(KAction *action, disabledDisabledActions) {
             if(ac) {
                 ac->addAction(action->objectName(), action);
             }
@@ -147,14 +150,14 @@ public:
     const KoInputDevice inputDevice;
     QWidget *dummyToolWidget;  // the widget shown in the toolDocker.
     QLabel *dummyToolLabel;
-    QList<QAction*> disabledActions; ///< disabled conflicting actions
-    QList<QAction*> disabledDisabledActions; ///< disabled conflicting actions that were already disabled
+    QList<KAction*> disabledActions; ///< disabled conflicting actions
+    QList<KAction*> disabledDisabledActions; ///< disabled conflicting actions that were already disabled
 };
 
 KoToolManager::Private::Private(KoToolManager *qq)
     : q(qq),
     canvasData(0),
-    layerEnabled(true)
+    layerExplicitlyDisabled(false)
 {
 }
 
@@ -183,15 +186,6 @@ CanvasData *KoToolManager::Private::createCanvasData(KoCanvasController *control
     return cd;
 }
 
-bool KoToolManager::Private::toolCanBeUsed(const QString &activationShapeId)
-{
-    if (layerEnabled)
-        return true;
-    if (activationShapeId.endsWith(QLatin1String("/always")))
-        return true;
-    return false;
-}
-
 void KoToolManager::Private::setup()
 {
     if (tools.size() > 0)
@@ -212,32 +206,27 @@ void KoToolManager::Private::setup()
     KoInputDeviceHandlerRegistry::instance();
 }
 
-void KoToolManager::Private::switchTool(KoToolBase *tool, bool temporary)
+void KoToolManager::Private::connectActiveTool()
 {
-    Q_UNUSED(temporary);
-    Q_ASSERT(tool);
-    if (canvasData == 0)
-        return;
-
-    if (canvasData->activeTool == tool && tool->toolId() != KoInteractionTool_ID)
-        return;
-
-    bool newActiveTool = canvasData->activeTool != 0;
-
-    if (newActiveTool) {
-        canvasData->activeTool->repaintDecorations();
-        // check if this tool is inputDeviceAgnostic and used by other devices, in which case we should not deactivate.
-        QList<CanvasData*> items = canvasses[canvasData->canvas];
-        foreach(CanvasData *cd, items) {
-            if (cd == canvasData) continue;
-            if (cd->activeTool == canvasData->activeTool) {
-                newActiveTool = false;
-                break;
-            }
-        }
+    if (canvasData->activeTool) {
+        connect(canvasData->activeTool, SIGNAL(cursorChanged(const QCursor &)),
+                q, SLOT(updateCursor(const QCursor &)));
+        connect(canvasData->activeTool, SIGNAL(activateTool(const QString &)),
+                q, SLOT(switchToolRequested(const QString &)));
+        connect(canvasData->activeTool, SIGNAL(activateTemporary(const QString &)),
+                q, SLOT(switchToolTemporaryRequested(const QString &)));
+        connect(canvasData->activeTool, SIGNAL(done()), q, SLOT(switchBackRequested()));
+        connect(canvasData->activeTool, SIGNAL(statusTextChanged(const QString &)),
+                q, SIGNAL(changedStatusText(const QString &)));
     }
 
-    if (newActiveTool) {
+    // we expect the tool to emit a cursor on activation.
+    updateCursor(Qt::ForbiddenCursor);
+}
+
+void KoToolManager::Private::disconnectActiveTool()
+{
+    if (canvasData->activeTool) {
         canvasData->deactivateToolActions();
         // repaint the decorations before we deactivate the tool as it might deleted
         // data needed for the repaint
@@ -253,24 +242,23 @@ void KoToolManager::Private::switchTool(KoToolBase *tool, bool temporary)
                    q, SIGNAL(changedStatusText(const QString &)));
     }
 
-    canvasData->activeTool = tool;
-
-    connect(canvasData->activeTool, SIGNAL(cursorChanged(const QCursor &)),
-            q, SLOT(updateCursor(const QCursor &)));
-    connect(canvasData->activeTool, SIGNAL(activateTool(const QString &)),
-            q, SLOT(switchToolRequested(const QString &)));
-    connect(canvasData->activeTool, SIGNAL(activateTemporary(const QString &)),
-            q, SLOT(switchToolTemporaryRequested(const QString &)));
-    connect(canvasData->activeTool, SIGNAL(done()), q, SLOT(switchBackRequested()));
-    connect(canvasData->activeTool, SIGNAL(statusTextChanged(const QString &)),
-            q, SIGNAL(changedStatusText(const QString &)));
-
     // emit a empty status text to clear status text from last active tool
     emit q->changedStatusText(QString());
+}
 
-    // we expect the tool to emit a cursor on activation.
-    updateCursor(Qt::ForbiddenCursor);
+void KoToolManager::Private::switchTool(KoToolBase *tool, bool temporary)
+{
+    Q_UNUSED(temporary);
+    Q_ASSERT(tool);
+    if (canvasData == 0)
+        return;
 
+    if (canvasData->activeTool == tool && tool->toolId() != KoInteractionTool_ID)
+        return;
+
+    disconnectActiveTool();
+    canvasData->activeTool = tool;
+    connectActiveTool();
     postSwitchTool(temporary);
 }
 
@@ -290,8 +278,6 @@ void KoToolManager::Private::switchTool(const QString &id, bool temporary)
 
     foreach(ToolHelper *th, tools) {
         if (th->id() == id) {
-            if (!toolCanBeUsed(th->activationShapeId()))
-                return;
             canvasData->activationShapeId = th->activationShapeId();
             break;
         }
@@ -341,12 +327,10 @@ void KoToolManager::Private::postSwitchTool(bool temporary)
     }
 
     if (canvasData->canvas->canvas()) {
-        KoCanvasBase *canvas = canvasData->canvas->canvas();
         // Caller of postSwitchTool expect this to be called to update the selected tool
-        KoToolProxy *tp = proxies.value(canvas);
-        if (tp)
-            tp->setActiveTool(canvasData->activeTool);
+        updateToolForProxy();
         canvasData->activeTool->activate(toolActivation, shapesToOperateOn);
+        KoCanvasBase *canvas = canvasData->canvas->canvas();
         canvas->updateInputMethodInfo();
     } else {
         canvasData->activeTool->activate(toolActivation, shapesToOperateOn);
@@ -389,11 +373,53 @@ void KoToolManager::Private::postSwitchTool(bool temporary)
     }
 }
 
+
+void KoToolManager::Private::switchCanvasData(CanvasData *cd)
+{
+    Q_ASSERT(cd);
+
+    KoCanvasBase *oldCanvas = 0;
+    KoInputDevice oldInputDevice;
+
+    if (canvasData) {
+        oldCanvas = canvasData->canvas->canvas();
+        oldInputDevice = canvasData->inputDevice;
+
+        if (canvasData->activeTool) {
+            disconnectActiveTool();
+        }
+
+        KoToolProxy *proxy = proxies.value(oldCanvas);
+        Q_ASSERT(proxy);
+        proxy->setActiveTool(0);
+    }
+
+    canvasData = cd;
+    inputDevice = canvasData->inputDevice;
+
+    if (canvasData->activeTool) {
+        connectActiveTool();
+        postSwitchTool(false);
+    }
+
+    if (oldInputDevice != canvasData->inputDevice) {
+        emit q->inputDeviceChanged(canvasData->inputDevice);
+    }
+
+    if (oldCanvas != canvasData->canvas->canvas()) {
+        emit q->changedCanvas(canvasData->canvas->canvas());
+    }
+
+    KoCanvasControllerWidget *canvasControllerWidget = dynamic_cast<KoCanvasControllerWidget*>(canvasData->canvas);
+    if (canvasControllerWidget) {
+        canvasControllerWidget->activate();
+    }
+}
+
+
 void KoToolManager::Private::toolActivated(ToolHelper *tool)
 {
     Q_ASSERT(tool);
-    if (!toolCanBeUsed(tool->activationShapeId()))
-        return;
 
     Q_ASSERT(canvasData);
     if (!canvasData) return;
@@ -421,13 +447,7 @@ void KoToolManager::Private::detachCanvas(KoCanvasController *controller)
             }
         }
         if (newCanvas) {
-            // activate the found canvas controller
-            canvasData = canvasses.value(newCanvas).first();
-            inputDevice = canvasData->inputDevice;
-            KoCanvasControllerWidget *canvasControllerWidget = dynamic_cast<KoCanvasControllerWidget*>(canvasData->canvas);
-            if (canvasControllerWidget) {
-                canvasControllerWidget->activate();
-            }
+            switchCanvasData(canvasses.value(newCanvas).first());
         } else {
             KoCanvasControllerWidget *canvasControllerWidget = dynamic_cast<KoCanvasControllerWidget*>(canvasData->canvas);
             if (canvasControllerWidget) {
@@ -545,34 +565,12 @@ void KoToolManager::Private::movedFocus(QWidget *from, QWidget *to)
         return;
     foreach(CanvasData *data, canvasses.value(newCanvas)) {
         if (data->inputDevice == inputDevice) {
-            if (canvasData) { // deactivate the old one.
-                updateCursor(Qt::ArrowCursor);
-                if (canvasData->activeTool) {
-                    canvasData->activeTool->deactivate();
-                    KoToolProxy *proxy = proxies.value(canvasData->canvas->canvas());
-                    Q_ASSERT(proxy);
-                    proxy->setActiveTool(0);
-                }
-            }
-
-            canvasData = data;
-            updateCursor(canvasData->activeTool->cursor());
-            KoCanvasControllerWidget *canvasControllerWidget = dynamic_cast<KoCanvasControllerWidget*>(canvasData->canvas);
-            if (canvasControllerWidget) {
-                canvasControllerWidget->activate();
-            }
-            postSwitchTool(false);
-            emit q->changedCanvas(canvasData ? canvasData->canvas->canvas() : 0);
+            switchCanvasData(data);
             return;
         }
     }
     // no such inputDevice for this canvas...
-    canvasData = canvasses.value(newCanvas).first();
-    inputDevice = canvasData->inputDevice;
-    if (canvasControllerWidget) {
-        canvasControllerWidget->activate();
-    }
-    emit q->changedCanvas(canvasData ? canvasData->canvas->canvas() : 0);
+    switchCanvasData(canvasses.value(newCanvas).first());
 }
 
 void KoToolManager::Private::updateCursor(const QCursor &cursor)
@@ -629,19 +627,20 @@ void KoToolManager::Private::selectionChanged(QList<KoShape*> shapes)
 
 void KoToolManager::Private::currentLayerChanged(const KoShapeLayer *layer)
 {
-    kDebug(30006) << "layer changed to" << layer;
-
     emit q->currentLayerChanged(canvasData->canvas, layer);
-    layerEnabled = layer == 0 || (layer->isEditable() && layer->isVisible());
+    layerExplicitlyDisabled = layer && !layer->isEditable();
+    updateToolForProxy();
 
-    kDebug(30006) << "and the layer enabled is" << (layerEnabled ? "true" : "false");
+    kDebug(30006) << "Layer changed to" << layer << "explicitly disabled:" << layerExplicitlyDisabled;
+}
 
+void KoToolManager::Private::updateToolForProxy()
+{
     KoToolProxy *proxy = proxies.value(canvasData->canvas->canvas());
-    kDebug(30006) << " and the proxy is" << proxy;
-    if (proxy) {
-        kDebug(30006) << " set" << canvasData->activeTool << (layerEnabled ? "enabled" : "disabled");
-        proxy->setActiveTool(toolCanBeUsed(canvasData->activationShapeId) ? canvasData->activeTool : 0);
-    }
+    if(!proxy) return;
+
+    bool canUseTool = !layerExplicitlyDisabled || canvasData->activationShapeId.endsWith(QLatin1String("/always"));
+    proxy->setActiveTool(canUseTool ? canvasData->activeTool : 0);
 }
 
 void KoToolManager::Private::switchInputDevice(const KoInputDevice &device)
@@ -656,7 +655,7 @@ void KoToolManager::Private::switchInputDevice(const KoInputDevice &device)
         // We do continue to switch between tablet devices, thought.
         return;
     }
-    inputDevice = device;
+
     QList<CanvasData*> items = canvasses[canvasData->canvas];
 
     // disable all actions for all tools in the all canvasdata objects for this canvas.
@@ -671,19 +670,12 @@ void KoToolManager::Private::switchInputDevice(const KoInputDevice &device)
     // search for a canvasdata object for the current input device
     foreach(CanvasData *cd, items) {
         if (cd->inputDevice == device) {
-            canvasData = cd;
-            if (cd->activeTool == 0)
+            switchCanvasData(cd);
+
+            if (!canvasData->activeTool) {
                 switchTool(KoInteractionTool_ID, false);
-            else {
-                postSwitchTool(false);
-                updateCursor(canvasData->activeTool->cursor());
             }
-            KoCanvasControllerWidget *canvasControllerWidget = dynamic_cast<KoCanvasControllerWidget*>(canvasData->canvas);
-            if (canvasControllerWidget) {
-                canvasControllerWidget->activate();
-            }
-            emit q->inputDeviceChanged(device);
-            emit q->changedCanvas(canvasData ? canvasData->canvas->canvas() : 0);
+
             return;
         }
     }
@@ -693,17 +685,12 @@ void KoToolManager::Private::switchInputDevice(const KoInputDevice &device)
     // switch to new canvas as the active one.
     QString oldTool = canvasData->activeToolId;
 
-    canvasData = cd;
     items.append(cd);
-    canvasses[canvasData->canvas] = items;
+    canvasses[cd->canvas] = items;
+
+    switchCanvasData(cd);
 
     q->switchToolRequested(oldTool);
-    emit q->inputDeviceChanged(device);
-    KoCanvasControllerWidget *canvasControllerWidget = dynamic_cast<KoCanvasControllerWidget*>(canvasData->canvas);
-    if (canvasControllerWidget) {
-        canvasControllerWidget->activate();
-    }
-    emit q->changedCanvas(canvasData ? canvasData->canvas->canvas() : 0);
 }
 
 void KoToolManager::Private::registerToolProxy(KoToolProxy *proxy, KoCanvasBase *canvas)
@@ -805,7 +792,7 @@ void KoToolManager::registerTools(KActionCollection *ac, KoCanvasController *con
         }
     }
     foreach(ToolHelper * th, d->tools) {
-        ToolAction* action = new ToolAction(this, th->id(), th->toolTip());
+        ToolAction* action = new ToolAction(this, th->id(), th->toolTip(), ac);
         action->setShortcut(th->shortcut());
         ac->addAction(th->id(), action);
     }
@@ -947,6 +934,8 @@ void KoToolManager::injectDeviceEvent(KoInputDeviceHandlerEvent * event)
 void KoToolManager::addDeferredToolFactory(KoToolFactoryBase *toolFactory)
 {
     ToolHelper *tool = new ToolHelper(toolFactory);
+    // make sure all plugins are loaded as otherwise we will not load them
+    d->setup();
     d->tools.append(tool);
 
     // connect to all tools so we can hear their button-clicks
@@ -995,8 +984,7 @@ QPair<QString, KoToolBase*> KoToolManager::createTools(KoCanvasController *contr
         origHash = d->canvasses.value(controller).first()->allTools;
     }
 
-    if (tool->inputDeviceAgnostic() && origHash.contains(tool->id())) {
-        // reuse ones that are marked as inputDeviceAgnostic();
+    if (origHash.contains(tool->id())) {
         return QPair<QString, KoToolBase*>(tool->id(), origHash.value(tool->id()));
     }
 
