@@ -237,8 +237,9 @@ void ChangeListCommand::redo()
             if (m_actions.value(i) == ChangeListCommand::RemoveList)
                 for (int j = 0; j < m_blocks.at(i).textList()->count(); j++) {
                     if (m_blocks.at(i).textList()->item(j) != m_blocks.at(i)) {
-                        if (KoTextBlockData *userData = dynamic_cast<KoTextBlockData*>(m_blocks.at(i).textList()->item(j).userData()))
-                            userData->setCounterWidth(-1.0);
+                        QTextBlock currentBlock = m_blocks.at(i).textList()->item(j);
+                        KoTextBlockData userData(currentBlock);
+                        userData.setCounterWidth(-1.0);
                         break;
                     }
                 }
@@ -253,14 +254,16 @@ void ChangeListCommand::redo()
                 listStyle->refreshLevelProperties(m_newProperties.value(i));
                 for (int j = 0; j < m_blocks.at(i).textList()->count(); j++) {
                     if (m_blocks.at(i).textList()->item(j) != m_blocks.at(i)) {
-                        if (KoTextBlockData *userData = dynamic_cast<KoTextBlockData*>(m_blocks.at(i).textList()->item(j).userData()))
-                            userData->setCounterWidth(-1.0);
+                        QTextBlock currentBlock = m_blocks.at(i).textList()->item(j);
+                        KoTextBlockData userData(currentBlock);
+                        userData.setCounterWidth(-1.0);
                         break;
                     }
                 }
             }
-            if (KoTextBlockData *userData = dynamic_cast<KoTextBlockData*>(m_blocks.at(i).userData()))
-                userData->setCounterWidth(-1.0);
+            QTextBlock currentBlock = m_blocks.at(i);
+            KoTextBlockData userData(currentBlock);
+            userData.setCounterWidth(-1.0);
         }
     }
     else {
@@ -305,8 +308,9 @@ void ChangeListCommand::undo()
             }
             for (int j = 0; j < m_blocks.at(i).textList()->count(); j++) {
                 if (m_blocks.at(i).textList()->item(j) != m_blocks.at(i)) {
-                    if (KoTextBlockData *userData = dynamic_cast<KoTextBlockData*>(m_blocks.at(i).textList()->item(j).userData()))
-                        userData->setCounterWidth(-1.0);
+                    QTextBlock currentBlock = m_blocks.at(i).textList()->item(j);
+                    KoTextBlockData userData(currentBlock);
+                    userData.setCounterWidth(-1.0);
                     break;
                 }
             }
@@ -319,8 +323,9 @@ void ChangeListCommand::undo()
             }
             for (int j = 0; j < m_blocks.at(i).textList()->count(); j++) {
                 if (m_blocks.at(i).textList()->item(j) != m_blocks.at(i)) {
-                    if (KoTextBlockData *userData = dynamic_cast<KoTextBlockData*>(m_blocks.at(i).textList()->item(j).userData()))
-                        userData->setCounterWidth(-1.0);
+                    QTextBlock currentBlock = m_blocks.at(i).textList()->item(j);
+                    KoTextBlockData userData(currentBlock);
+                    userData.setCounterWidth(-1.0);
                     break;
                 }
             }
@@ -334,16 +339,18 @@ void ChangeListCommand::undo()
                 m_oldList.value(i)->updateStoredList(m_blocks.at(i));
                 for (int j = 0; j < m_blocks.at(i).textList()->count(); j++) {
                     if (m_blocks.at(i).textList()->item(j) != m_blocks.at(i)) {
-                        if (KoTextBlockData *userData = dynamic_cast<KoTextBlockData*>(m_blocks.at(i).textList()->item(j).userData()))
-                            userData->setCounterWidth(-1.0);
+                        QTextBlock currentBlock = m_blocks.at(i).textList()->item(j);
+                        KoTextBlockData userData(currentBlock);
+                        userData.setCounterWidth(-1.0);
                         break;
                     }
                 }
             }
         }
 
-        if (KoTextBlockData *userData = dynamic_cast<KoTextBlockData*>(m_blocks.at(i).userData()))
-            userData->setCounterWidth(-1.0);
+        QTextBlock currentBlock = m_blocks.at(i);
+        KoTextBlockData userData(currentBlock);
+        userData.setCounterWidth(-1.0);
     }
 }
 
