@@ -29,6 +29,7 @@
 #include <QList>
 #include <QSignalMapper>
 
+#include <KStringHandler>
 #include <KLocale>
 #include <KDebug>
 
@@ -284,7 +285,7 @@ void StylesModel::addParagraphStyle(KoParagraphStyle *style)
             s = m_draftParStyleList[*begin];
         // s should be found as the manager and the m_styleList should be in sync
         Q_ASSERT(s);
-        if (QString::localeAwareCompare(style->name(), s->name()) < 0) {
+        if (KStringHandler::naturalCompare(style->name(),s->name()) < 0) {
             break;
         }
         ++index;
@@ -300,7 +301,7 @@ bool sortParagraphStyleByName(KoParagraphStyle *style1, KoParagraphStyle *style2
 {
     Q_ASSERT(style1);
     Q_ASSERT(style2);
-    return QString::localeAwareCompare(style1->name(), style2->name()) < 0;
+    return KStringHandler::naturalCompare(style1->name(), style2->name()) < 0;
 }
 
 void StylesModel::updateParagraphStyles()
@@ -314,9 +315,11 @@ void StylesModel::updateParagraphStyles()
     qSort(styles.begin(), styles.end(), sortParagraphStyleByName);
 
     foreach(KoParagraphStyle *style, styles) {
-        m_styleList.append(style->styleId());
-        m_styleMapper->setMapping(style, style->styleId());
-        connect(style, SIGNAL(nameChanged(const QString&)), m_styleMapper, SLOT(map()));
+        if (style != m_styleManager->defaultParagraphStyle()) { //The default paragraph style is not user selectable. It only provides individual property defaults and is not a style per say.
+            m_styleList.append(style->styleId());
+            m_styleMapper->setMapping(style, style->styleId());
+            connect(style, SIGNAL(nameChanged(const QString&)), m_styleMapper, SLOT(map()));
+        }
     }
 
     endResetModel();
@@ -340,7 +343,7 @@ void StylesModel::addCharacterStyle(KoCharacterStyle *style)
             s = m_draftCharStyleList[*begin];
         // s should be found as the manager and the m_styleList should be in sync
         Q_ASSERT(s);
-        if (QString::localeAwareCompare(style->name(), s->name()) < 0) {
+        if (KStringHandler::naturalCompare(style->name(),s->name()) < 0) {
             break;
         }
         ++index;
@@ -356,7 +359,7 @@ bool sortCharacterStyleByName(KoCharacterStyle *style1, KoCharacterStyle *style2
 {
     Q_ASSERT(style1);
     Q_ASSERT(style2);
-    return QString::localeAwareCompare(style1->name(), style2->name()) < 0;
+    return KStringHandler::naturalCompare(style1->name(), style2->name()) < 0;
 }
 
 void StylesModel::updateCharacterStyles()
@@ -374,9 +377,11 @@ void StylesModel::updateCharacterStyles()
     qSort(styles.begin(), styles.end(), sortCharacterStyleByName);
 
     foreach(KoCharacterStyle *style, styles) {
-        m_styleList.append(style->styleId());
-        m_styleMapper->setMapping(style, style->styleId());
-        connect(style, SIGNAL(nameChanged(const QString&)), m_styleMapper, SLOT(map()));
+        if (style != m_styleManager->defaultCharacterStyle()) { //The default character style is not user selectable. It only provides individual property defaults and is not a style per say.
+	    m_styleList.append(style->styleId());
+            m_styleMapper->setMapping(style, style->styleId());
+            connect(style, SIGNAL(nameChanged(const QString&)), m_styleMapper, SLOT(map()));
+	}
     }
 
     endResetModel();
@@ -428,7 +433,7 @@ void StylesModel::updateName(int styleId)
                         s = m_draftParStyleList[*begin];
                     // s should be found as the manager and the m_styleList should be in sync
                     Q_ASSERT(s);
-                    if (QString::localeAwareCompare(paragStyle->name(), s->name()) < 0) {
+                    if (KStringHandler::naturalCompare(paragStyle->name(), s->name()) < 0) {
                         break;
                     }
                     ++newIndex;
@@ -465,7 +470,7 @@ void StylesModel::updateName(int styleId)
                         s = m_draftCharStyleList[*begin];
                     // s should be found as the manager and the m_styleList should be in sync
                     Q_ASSERT(s);
-                    if (QString::localeAwareCompare(characterStyle->name(), s->name()) < 0) {
+                    if (KStringHandler::naturalCompare(characterStyle->name(), s->name()) < 0) {
                         break;
                     }
                     ++newIndex;
@@ -485,6 +490,9 @@ void StylesModel::updateName(int styleId)
 
 QModelIndex StylesModel::firstStyleIndex()
 {
+    if (!m_styleList.count()) {
+        return QModelIndex();
+    }
     return createIndex(m_styleList.indexOf(m_styleList.at(0)), 0, m_styleList.at(0));
 }
 
